[![DOI](https://zenodo.org/badge/39147824.svg)](https://doi.org/10.7717/peerj.4925)
![Conda](https://img.shields.io/conda/dn/bioconda/amptk)
# AMPtk
### NGS AMPlicon Tool Kit:

Documentation: http://amptk.readthedocs.io/

#### Citation

Palmer JM, Jusino MA, Banik MT, Lindner DL. 2018. Non-biological synthetic spike-in controls and the AMPtk software pipeline improve mycobiome data. PeerJ 6:e4925; DOI 10.7717/peerj.4925.

[https://peerj.com/articles/4925/](https://peerj.com/articles/4925/)

